/*
** Module   : Match.java
** Abstract : represents a match of a specific condition in a specific file
**            for use in calculating statistics
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -------------------Description--------------------
** 001 GES 20050225   @20122 Created initial version supporting the
**                           storage of a line number, column number and
**                           arbitrary text.
** 002 GES 20130206          Moved class to the pattern package.
*/ 

package com.goldencode.p2j.pattern;

/**
 * A simple container class to store and access file and text related  
 * information about a single specific match to a condition within a specific
 * file.
 * <p>
 * This supports the storage of a line number, column number and a string.
 *
 * @author    GES
 * @version   1.0.0
 */
public class Match
{   
   /** Line number of the beginning of the match in the file. */
   private int line = 0;
   
   /** Column number of the beginning of the match in the file. */
   private int column = 0;
   
   /** The user-defined text of the match. */
   private String text = null;   
   
   /**
    * Constructs an instance with user-defined data.
    *
    * @param    line
    *           The line number of the beginning of the match in the file.
    *
    * @param    column
    *           The column number of the beginning of the match in the file.
    *
    * @param    text
    *           Stores the text of the match.
    */
   public Match(int line, int column, String text)
   {
      this.line   = line;
      this.column = column;
      this.text   = text;
   }
   
   /**
    * Accesses the line number of the beginning of the match in the file.
    *
    * @return   The line number of the beginning of the match in the file.
    */
   public int getLine()
   {
      return line;
   }
   
   /**
    * Sets the line number of the beginning of the match in the file.
    *
    * @param    line
    *           The line number of the beginning of the match in the file.
    */
   public void setLine(int line)
   {
      this.line = line;
   }
   
   /**
    * Accesses the column number of the beginning of the match in the file.
    *
    * @return   The column number of the beginning of the match in the file.
    */
   public int getColumn()
   {
      return column;
   }
   
   /**
    * Sets the column number of the beginning of the match in the file.
    *
    * @param    column
    *           The column number of the beginning of the match in the file.
    */
   public void setColumn(int column)
   {
      this.column = column;
   }
   
   /**
    * Accesses the user-defined text for this match.
    *
    * @return   The user-defined text for this match.
    */
   public String getText()
   {
      return text;
   }
   
   /**
    * Sets the  user-defined text for this match.
    *
    * @param    text
    *           The user-defined text for this match.
    */
   public void setText(String text)
   {
      this.text = text;
   }   
}
